@@ -1,9 +1,9 @@
 package Code::TidyAll::Plugin::Go::Vet;
-$Code::TidyAll::Plugin::Go::Vet::VERSION = '0.01';
+$Code::TidyAll::Plugin::Go::Vet::VERSION = '0.02';
 use strict;
 use warnings;
 
-use Capture::Tiny qw(capture_merged);
+use IPC::Run3 qw( run3 );
 use Moo;
 
 extends 'Code::TidyAll::Plugin';
@@ -14,9 +14,13 @@ sub validate_file {
     my ( $self, $file ) = @_;
 
     my $cmd = join q{ }, $self->cmd, $self->argv, $file;
-    my $output = capture_merged { system($cmd) and die "$cmd failed"; };
 
-    die "$output\n" if $output;
+    my $output;
+    run3( $cmd, \undef, \$output, \$output );
+    if ( $? > 0 ) {
+        $output ||= 'problem running ' . $self->cmd;
+        die "$output\n";
+    }
 }
 
 1;
